@@ -16,10 +16,9 @@ def plotsklearnresult(configini,videoSetting, frameSetting):
         config.read(configFile)
     except MissingSectionHeaderError:
         print('ERROR:  Not a valid project_config file. Please check the project_config.ini path.')
-    csv_dir = config.get('General settings', 'csv_path')
-    csv_dir_in = os.path.join(csv_dir, "machine_results")
     animalsNo = config.getint('General settings', 'animal_no')
     projectPath = config.get('General settings', 'project_path')
+    csv_dir_in = os.path.join(projectPath, 'csv', "machine_results")
     frames_dir_out = config.get('Frame settings', 'frames_dir_out')
     frames_dir_out = os.path.join(frames_dir_out, 'sklearn_results')
     poseConfSetting = config.get('create ensemble settings', 'pose_estimation_body_parts')
